@@ -218,6 +218,8 @@ class StateWatcher(models.Model):
     )
     last_state = models.CharField(max_length=1073741824, editable=False)
 
+    scheduled_watchers = {}
+
     def __str__(self):
         return self.name
 
@@ -339,12 +341,55 @@ class StateWatcher(models.Model):
                     f" {exc_tb.tb_lineno}\n{traceback.format_exc()}"
                 )
 
+    @classmethod
+    def _update_scheduled_jobs(cls):
+        added_jobs = {}
+        removed_jobs = {}
+        modified_jobs = {}
+        for id in cls.scheduled_watchers:
+            if not cls.objects.filter(id=id).exists():
+                removed_jobs[id] = cls.objects.filter(id=id)[0]
+            elif cls.objects.filter(id=id)[0].interval != \
+                    cls.scheduled_watchers[id]["interval"]:
+                modified_jobs[id] = cls.objects.filter(id=id)[0]
+        for obj in cls.objects.all():
+            if obj.id not in cls.scheduled_watchers:
+                added_jobs[obj.id] = obj
+        for id in added_jobs:
+            job_obj = added_jobs[id]
+            cls.scheduled_watchers[id] = {
+                "job": schedule.every(
+                    job_obj.interval
+                ).minutes.do(job_obj.refresh),
+                "interval": job_obj.interval
+            }
+        for id in removed_jobs:
+            schedule.cancel_job(cls.scheduled_watchers[id]["job"])
+            del cls.scheduled_watchers[id]
+        for id in modified_jobs:
+            job_obj = modified_jobs[id]
+            schedule.cancel_job(cls.scheduled_watchers[id]["job"])
+            cls.scheduled_watchers[id]["job"] = \
+                schedule.every(job_obj.interval).minutes.do(job_obj.refresh)
+            cls.scheduled_watchers[id]["interval"] = job_obj.interval
+        if len(added_jobs):
+            logging.info(f"{len(added_jobs)} Watchers added")
+        if len(removed_jobs):
+            logging.info(f"{len(removed_jobs)} Watchers removed")
+        if len(modified_jobs):
+            logging.info(f"{len(modified_jobs)} Watchers modified")
+
     @classmethod
     def start(cls):
         """Start all StateWatchers in Alert360
         """
         for sw in cls.objects.all():
-            schedule.every(sw.interval).minutes.do(sw.refresh)
+            cls.scheduled_watchers[sw.id] = \
+                {
+                    "job": schedule.every(sw.interval).minutes.do(sw.refresh),
+                    "interval": sw.interval
+            }
+        schedule.every(2).seconds.do(cls._update_scheduled_jobs)
         while True:
             schedule.run_pending()
             time.sleep(1)
